@@ -24,14 +24,14 @@ $skinJsFile = getSkinFile( 'js/skin.js' );
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
-  <title><?= ZM_WEB_TITLE_PREFIX ?></title>
+  <title><?php echo ZM_WEB_TITLE_PREFIX ?></title>
   <script type="text/javascript">
 <?php
 require_once( $skinJsPhpFile );
 ?>
   </script>
 
-  <script type="text/javascript" src="<?= $skinJsFile ?>"></script>
+  <script type="text/javascript" src="<?php echo $skinJsFile ?>"></script>
   <script type="text/javascript">
 <?php
 if ( !$debug )
